@@ -67,9 +67,9 @@ public class ResourceServlet extends HttpServlet {
 
   private static Set<String> knownParameters = new HashSet<>(
       Arrays.asList("type", "running", "search", "lookup", "fingerprint",
-          "country", "as", "flag", "first_seen_days", "last_seen_days",
-          "contact", "order", "limit", "offset", "fields", "family", "version",
-          "os", "host_name", "recommended_version"));
+          "country", "as", "as_name", "flag", "first_seen_days",
+          "last_seen_days", "contact", "order", "limit", "offset", "fields",
+          "family", "version", "os", "host_name", "recommended_version"));
 
   private static Set<String> illegalSearchQualifiers =
       new HashSet<>(Arrays.asList(("search,fingerprint,order,limit,"
@@ -211,24 +211,22 @@ public class ResourceServlet extends HttpServlet {
       rh.setRunning(runningRequested ? "true" : "false");
     }
     if (parameterMap.containsKey("lookup")) {
-      String lookupParameter = this.parseFingerprintParameter(
+      String[] lookupParameter = this.parseFingerprintParameter(
           parameterMap.get("lookup"));
       if (lookupParameter == null) {
         response.sendError(HttpServletResponse.SC_BAD_REQUEST);
         return;
       }
-      String fingerprint = lookupParameter.toUpperCase();
-      rh.setLookup(fingerprint);
+      rh.setLookup(lookupParameter);
     }
     if (parameterMap.containsKey("fingerprint")) {
-      String fingerprintParameter = this.parseFingerprintParameter(
+      String[] fingerprintParameter = this.parseFingerprintParameter(
           parameterMap.get("fingerprint"));
-      if (fingerprintParameter == null) {
+      if (null == fingerprintParameter || 1 != fingerprintParameter.length) {
         response.sendError(HttpServletResponse.SC_BAD_REQUEST);
         return;
       }
-      String fingerprint = fingerprintParameter.toUpperCase();
-      rh.setFingerprint(fingerprint);
+      rh.setFingerprint(fingerprintParameter[0]);
     }
     if (parameterMap.containsKey("country")) {
       String countryCodeParameter = this.parseCountryCodeParameter(
@@ -240,7 +238,7 @@ public class ResourceServlet extends HttpServlet {
       rh.setCountry(countryCodeParameter);
     }
     if (parameterMap.containsKey("as")) {
-      String asNumberParameter = this.parseAsNumberParameter(
+      String[] asNumberParameter = this.parseAsNumberParameter(
           parameterMap.get("as"));
       if (asNumberParameter == null) {
         response.sendError(HttpServletResponse.SC_BAD_REQUEST);
@@ -248,6 +246,15 @@ public class ResourceServlet extends HttpServlet {
       }
       rh.setAs(asNumberParameter);
     }
+    if (parameterMap.containsKey("as_name")) {
+      String[] asNameParameter = this.parseAsNameParameter(
+          parameterMap.get("as_name"));
+      if (null == asNameParameter) {
+        response.sendError(HttpServletResponse.SC_BAD_REQUEST);
+        return;
+      }
+      rh.setAsName(asNameParameter);
+    }
     if (parameterMap.containsKey("flag")) {
       String flagParameter = this.parseFlagParameter(
           parameterMap.get("flag"));
@@ -360,14 +367,13 @@ public class ResourceServlet extends HttpServlet {
       rh.setLimit(limitParameter);
     }
     if (parameterMap.containsKey("family")) {
-      String familyParameter = this.parseFingerprintParameter(
+      String[] familyParameter = this.parseFingerprintParameter(
           parameterMap.get("family"));
-      if (familyParameter == null) {
+      if (null == familyParameter || 1 != familyParameter.length) {
         response.sendError(HttpServletResponse.SC_BAD_REQUEST);
         return;
       }
-      String family = familyParameter.toUpperCase();
-      rh.setFamily(family);
+      rh.setFamily(familyParameter[0]);
     }
     rh.handleRequest();
     long parsedRequestMillis = System.currentTimeMillis();
@@ -473,18 +479,14 @@ public class ResourceServlet extends HttpServlet {
   }
 
   private static Pattern fingerprintParameterPattern =
-      Pattern.compile("^[0-9a-zA-Z]{1,40}$");
+      Pattern.compile("((^|,)[0-9a-zA-Z]{40})+$");
 
-  private String parseFingerprintParameter(String parameter) {
+  private String[] parseFingerprintParameter(String parameter) {
     if (!fingerprintParameterPattern.matcher(parameter).matches()) {
       /* Fingerprint contains non-hex character(s). */
       return null;
     }
-    if (parameter.length() != 40) {
-      /* Only full fingerprints are accepted. */
-      return null;
-    }
-    return parameter;
+    return parameter.toUpperCase().split(",");
   }
 
   private static Pattern countryCodeParameterPattern =
@@ -500,14 +502,30 @@ public class ResourceServlet extends HttpServlet {
   }
 
   private static Pattern asNumberParameterPattern =
-      Pattern.compile("^[asAS]{0,2}[0-9]{1,10}$");
+      Pattern.compile("((^|,)([aA][sS])?[1-9][0-9]{0,9})+$");
 
-  private String parseAsNumberParameter(String parameter) {
+  private String[] parseAsNumberParameter(String parameter) {
     if (!asNumberParameterPattern.matcher(parameter).matches()) {
       /* AS number contains illegal character(s). */
       return null;
     }
-    return parameter;
+    String[] parameterParts = parameter.toUpperCase().split(",");
+    String[] parsedParameter = new String[parameterParts.length];
+    for (int i = 0; i < parameterParts.length; i++) {
+      parsedParameter[i] = (!parameterParts[i].startsWith("AS") ? "AS" : "")
+          + parameterParts[i];
+    }
+    return parsedParameter;
+  }
+
+  private String[] parseAsNameParameter(String parameter) {
+    for (char c : parameter.toCharArray()) {
+      if (c < 32 || c >= 127) {
+        /* Only accept printable ASCII. */
+        return null;
+      }
+    }
+    return parameter.toLowerCase().split(" ");
   }
 
   private static Pattern flagPattern =
