@@ -14,10 +14,7 @@ import org.torproject.onionoo.docs.DummyDocumentStore;
 import org.torproject.onionoo.docs.UpdateStatus;
 
 import com.fasterxml.jackson.annotation.JsonAutoDetect;
-import com.fasterxml.jackson.annotation.JsonInclude;
-import com.fasterxml.jackson.annotation.PropertyAccessor;
 import com.fasterxml.jackson.databind.ObjectMapper;
-import com.fasterxml.jackson.databind.PropertyNamingStrategy;
 import org.junit.Before;
 import org.junit.Test;
 
@@ -39,11 +36,7 @@ import java.util.TreeSet;
  * which tests servlet specifics. */
 public class ResourceServletTest {
 
-  private static ObjectMapper objectMapper = new ObjectMapper()
-      .setPropertyNamingStrategy(PropertyNamingStrategy.SNAKE_CASE)
-      .setSerializationInclusion(JsonInclude.Include.NON_EMPTY)
-      .setVisibility(PropertyAccessor.ALL, JsonAutoDetect.Visibility.NONE)
-      .setVisibility(PropertyAccessor.FIELD, JsonAutoDetect.Visibility.ANY);
+  private static ObjectMapper objectMapper = new ObjectMapper();
 
   private SortedMap<String, org.torproject.onionoo.docs.SummaryDocument> relays;
   private SortedMap<String, org.torproject.onionoo.docs.SummaryDocument>
@@ -147,6 +140,7 @@ public class ResourceServletTest {
         false, new TreeSet<>(Arrays.asList(new String[] { "Running",
             "Valid" })), 20L, "de",
         DateTimeHelper.parse("2013-04-18 05:00:00"), "AS8767",
+        "m-net telekommunikations gmbh",
         "torkaz <klaus dot zufall at gmx dot de> "
         + "<fb-token:np5_g_83jmf=>", new TreeSet<>(Arrays.asList(
         new String[] { "001C13B3A55A71B977CA65EC85539D79C653A3FC",
@@ -166,7 +160,8 @@ public class ResourceServletTest {
         DateTimeHelper.parse("2013-04-24 12:00:00"), true,
         new TreeSet<>(Arrays.asList(new String[] { "Fast", "Named",
             "Running", "V2Dir", "Valid" })), 1140L, "us",
-        DateTimeHelper.parse("2013-04-16 18:00:00"), "AS7922", null,
+        DateTimeHelper.parse("2013-04-16 18:00:00"), "AS7922",
+        "comcast cable communications, llc", null,
         new TreeSet<String>(Arrays.asList(new String[] {
             "000C5F55BD4814B917CC474BD537F1A3B33CCE2A" })),
         new TreeSet<>(Arrays.asList(new String[] {
@@ -185,6 +180,7 @@ public class ResourceServletTest {
         new TreeSet<>(Arrays.asList(new String[] { "Fast",
             "Running", "Unnamed", "V2Dir", "Valid" })), 63L, "a1",
         DateTimeHelper.parse("2013-04-16 18:00:00"), "AS6830",
+        "liberty global operations b.v.",
         "1024d/51e2a1c7 \"steven j. murdoch\" "
         + "<tor+steven.murdoch@cl.cam.ac.uk> <fb-token:5sr_k_zs2wm=>",
         new TreeSet<String>(), new TreeSet<String>(), "0.2.3.24-rc-dev",
@@ -198,7 +194,7 @@ public class ResourceServletTest {
         Arrays.asList(new String[] { "10.199.7.176" }),
         DateTimeHelper.parse("2013-04-21 18:07:03"), false,
         new TreeSet<>(Arrays.asList(new String[] { "Valid" })), -1L,
-        null, DateTimeHelper.parse("2013-04-20 15:37:04"), null, null,
+        null, DateTimeHelper.parse("2013-04-20 15:37:04"), null, null, null,
         null, null, "0.2.2.39", null, null, null, null, true);
     this.bridges.put("0000831B236DFF73D409AD17B40E2A728A53994F",
         bridgeec2bridgercc7f31fe);
@@ -208,7 +204,7 @@ public class ResourceServletTest {
         new String[] { "10.0.52.84" }),
         DateTimeHelper.parse("2013-04-20 17:37:04"), false,
         new TreeSet<>(Arrays.asList(new String[] { "Valid" })), -1L,
-        null, DateTimeHelper.parse("2013-04-14 07:07:05"), null, null,
+        null, DateTimeHelper.parse("2013-04-14 07:07:05"), null, null, null,
         null, null, null, null, null, null, null, null);
     this.bridges.put("0002D9BDBBC230BD9C78FF502A16E0033EF87E0C",
         bridgeUnnamed);
@@ -219,7 +215,7 @@ public class ResourceServletTest {
         DateTimeHelper.parse("2013-04-24 01:07:04"), true,
         new TreeSet<>(Arrays.asList(new String[] { "Running",
             "Valid" })), -1L, null,
-        DateTimeHelper.parse("2013-01-16 21:07:04"), null, null, null,
+        DateTimeHelper.parse("2013-01-16 21:07:04"), null, null, null, null,
         null, "0.2.4.4-alpha-dev", "windows 7", null, null, null, false);
     this.bridges.put("1FEDE50ED8DBA1DD9F9165F78C8131E4A44AB756",
         bridgegummy);
@@ -357,6 +353,7 @@ public class ResourceServletTest {
   }
 
   @SuppressWarnings("MemberName")
+  @JsonAutoDetect(fieldVisibility = JsonAutoDetect.Visibility.ANY)
   private static class SummaryDocument {
     private String version;
     private String next_major_version_scheduled;
@@ -372,6 +369,7 @@ public class ResourceServletTest {
   }
 
   @SuppressWarnings("MemberName")
+  @JsonAutoDetect(fieldVisibility = JsonAutoDetect.Visibility.ANY)
   private static class RelaySummary {
     private String n;
     private String f;
@@ -380,6 +378,7 @@ public class ResourceServletTest {
   }
 
   @SuppressWarnings("MemberName")
+  @JsonAutoDetect(fieldVisibility = JsonAutoDetect.Visibility.ANY)
   private static class BridgeSummary {
     private String n;
     private String h;
@@ -1045,6 +1044,20 @@ public class ResourceServletTest {
         null, 0, null);
   }
 
+  @Test(timeout = 100)
+  public void testLookupTwoFingerprints() {
+    this.assertSummaryDocument(
+        "/summary?lookup=000C5F55BD4814B917CC474BD537F1A3B33CCE2A,"
+        + "1FEDE50ED8DBA1DD9F9165F78C8131E4A44AB756", 1,
+        new String[] { "TorkaZ" }, 1,   new String[] { "gummy" });
+  }
+
+  @Test(timeout = 100)
+  public void testLookupFingerprintTrailingComma() {
+    this.assertErrorStatusCode(
+        "/summary?lookup=000C5F55BD4814B917CC474BD537F1A3B33CCE2A,", 400);
+  }
+
   @Test(timeout = 100)
   public void testFingerprintRelayFingerprint() {
     this.assertSummaryDocument(
@@ -1160,6 +1173,36 @@ public class ResourceServletTest {
         "/summary?as=AS 8767", 400);
   }
 
+  @Test(timeout = 100)
+  public void testAs8767Or7922() {
+    this.assertSummaryDocument("/summary?as=8767,7922", 2,
+        new String[] { "TorkaZ", "Ferrari458" }, 0, null);
+  }
+
+  @Test(timeout = 100)
+  public void testAsNameComcast() {
+    this.assertSummaryDocument("/summary?as_name=Comcast", 1, null, 0, null);
+  }
+
+  @Test(timeout = 100)
+  public void testAsNameComcastCable() {
+    this.assertSummaryDocument("/summary?as_name=Comcast Cable",
+        1, null, 0, null);
+  }
+
+  @Test(timeout = 100)
+  public void testAsNameCableComcast() {
+    this.assertSummaryDocument("/summary?as_name=Cable Comcast",
+        1, null, 0, null);
+  }
+
+  @Test(timeout = 100)
+  public void testAsNameMit() {
+    this.assertSummaryDocument(
+        "/summary?as_name=Massachusetts Institute of Technology",
+        0, null, 0, null);
+  }
+
   @Test(timeout = 100)
   public void testFlagRunning() {
     this.assertSummaryDocument(
