@@ -1,4 +1,4 @@
-/* Copyright 2014--2017 The Tor Project
+/* Copyright 2014--2018 The Tor Project
  * See LICENSE for licensing information */
 
 package org.torproject.onionoo.updater;
@@ -8,6 +8,7 @@ import org.torproject.descriptor.DirectorySignature;
 import org.torproject.descriptor.NetworkStatusEntry;
 import org.torproject.descriptor.RelayNetworkStatusConsensus;
 
+import java.io.File;
 import java.util.List;
 import java.util.SortedMap;
 import java.util.SortedSet;
@@ -20,6 +21,10 @@ public class DummyConsensus implements RelayNetworkStatusConsensus {
     return null;
   }
 
+  public int getRawDescriptorLength() {
+    return 0;
+  }
+
   public List<String> getAnnotations() {
     return null;
   }
@@ -28,6 +33,10 @@ public class DummyConsensus implements RelayNetworkStatusConsensus {
     return null;
   }
 
+  public File getDescriptorFile() {
+    return null;
+  }
+
   public int getNetworkStatusVersion() {
     return 0;
   }
@@ -123,6 +132,10 @@ public class DummyConsensus implements RelayNetworkStatusConsensus {
     return null;
   }
 
+  public String getDigestSha1Hex() {
+    return null;
+  }
+
   public List<String> getPackageLines() {
     return null;
   }
@@ -130,5 +143,38 @@ public class DummyConsensus implements RelayNetworkStatusConsensus {
   public List<DirectorySignature> getSignatures() {
     return null;
   }
+
+  public int getSharedRandPreviousNumReveals() {
+    return -1;
+  }
+
+  public String getSharedRandPreviousValue() {
+    return null;
+  }
+
+  public int getSharedRandCurrentNumReveals() {
+    return -1;
+  }
+
+  public String getSharedRandCurrentValue() {
+    return null;
+  }
+
+  public SortedMap<String, SortedSet<Long>> getRecommendedClientProtocols() {
+    return null;
+  }
+
+  public SortedMap<String, SortedSet<Long>> getRecommendedRelayProtocols() {
+    return null;
+  }
+
+  public SortedMap<String, SortedSet<Long>> getRequiredClientProtocols() {
+    return null;
+  }
+
+  public SortedMap<String, SortedSet<Long>> getRequiredRelayProtocols() {
+    return null;
+  }
+
 }
 
